@@ -1,5 +1,5 @@
 #!/bin/sh
-# Copyright (C) 2002-2012 Free Software Foundation, Inc.
+# Copyright (C) 2002-2013 Free Software Foundation, Inc.
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -17,7 +17,7 @@
 # Check that non-conditional primaries cannot use directories defined
 # in some conditions (but not others).
 
-. ./defs || Exit 1
+. test-init.sh
 
 cat >>configure.ac << 'EOF'
 AM_CONDITIONAL([USE_FOO], [true])
@@ -32,7 +32,7 @@ EOF
 
 $ACLOCAL
 AUTOMAKE_fails
-grep ' USE_FOO' stderr && Exit 1
+grep ' USE_FOO' stderr && exit 1
 grep '!USE_FOO' stderr
 
 :
